import React from 'react';
import * as stories from './ClearButton.stories';
import { composeStories, fireEvent, generateSnapshots, render, screen, userEvent, } from '../../tests/helpers';
const { Default, Large } = composeStories(stories);
describe('<ClearButton>', () => {
    generateSnapshots(stories);
    it('renders a default clear button', () => {
        render(React.createElement(Default, null));
        expect(screen.getByRole('button').className).toBe('close btn-close rbt-close');
    });
    it('renders a large clear button', () => {
        render(React.createElement(Large, null));
        expect(screen.getByRole('button').className).toContain('rbt-close-lg');
    });
    it('registers a click', async () => {
        const user = userEvent.setup();
        const onClick = jest.fn();
        render(React.createElement(Default, { onClick: onClick }));
        const button = screen.getByRole('button');
        await user.click(button);
        expect(onClick).toHaveBeenCalledTimes(1);
    });
    it('prevents the default backspace behavior', () => {
        const onKeyDown = jest.fn();
        let isDefault;
        render(React.createElement(Default, { onKeyDown: onKeyDown }));
        const button = screen.getByRole('button');
        isDefault = fireEvent.keyDown(button, {
            key: 'Backspace',
        });
        expect(onKeyDown).toHaveBeenCalledTimes(1);
        expect(isDefault).toBe(false);
        isDefault = fireEvent.keyDown(button, {
            key: 'Enter',
        });
        expect(onKeyDown).toHaveBeenCalledTimes(2);
        expect(isDefault).toBe(true);
    });
});
