import React from 'react';
import Highlighter from './Highlighter';
import { render } from '../../tests/helpers';
function getMatches(nodes) {
    const arr = Array.from(nodes);
    return arr.filter((node) => node.tagName === 'MARK');
}
describe('<Highlighter>', () => {
    it('does not highlight text when there is no search string', () => {
        const { container } = render(React.createElement(Highlighter, { search: "" }, "California"));
        const nodes = container.childNodes;
        expect(nodes).toHaveLength(1);
        expect(nodes.item(0)).toHaveTextContent('California');
        expect(getMatches(nodes)).toHaveLength(0);
    });
    it('does not highlight text when there is no match', () => {
        const { container } = render(React.createElement(Highlighter, { search: "x" }, "California"));
        expect(getMatches(container.childNodes)).toHaveLength(0);
    });
    it('handles an empty child string', () => {
        const { container } = render(React.createElement(Highlighter, { search: "foo" }, ''));
        expect(container.childNodes.item(0)).toBeNull();
    });
    it('highlights text within a string', () => {
        const { container } = render(React.createElement(Highlighter, { search: "i" }, "California"));
        const nodes = container.childNodes;
        const matches = getMatches(nodes);
        expect(nodes.length).toBe(5);
        expect(nodes.item(0)).toHaveTextContent('Cal');
        expect(matches.length).toBe(2);
        expect(matches[0]).toHaveTextContent('i');
        expect(matches[0]).toHaveClass('rbt-highlight-text');
    });
    it('highlights text at the beginning of a string', () => {
        const { container } = render(React.createElement(Highlighter, { search: "cal" }, "California"));
        const nodes = container.childNodes;
        const matches = getMatches(nodes);
        expect(nodes).toHaveLength(2);
        expect(nodes.item(0)).toHaveTextContent('Cal');
        expect(matches).toHaveLength(1);
        expect(matches[0]).toHaveTextContent('Cal');
    });
    it('adds custom classnames to the highlighted children', () => {
        const { container } = render(React.createElement(Highlighter, { highlightClassName: "foo", search: "i" }, "California"));
        expect(getMatches(container.childNodes)[0]).toHaveClass('foo');
    });
});
